#
# Parse through full_drugbank.xml, the drug database from Drugbank.ca, and
# output drug_approval_status.json. This will map each drug name to an
# array of "groups" that its falls under, aka its approval status.
#
# The following is the set of possible groups, as per the schema:
#
# { "approved", "illicit", "experimental", "withdrawn", "nutraceutical",
#   "investigational", "vet_approved" }
#
#
# Joel Rorseth
# February 15, 2018
#

import xmltodict as xd
import json
from collections import defaultdict

# Open drug database XML file into a dict object
with open("../Datasets/full_drugbank.xml") as fd:
    doc = xd.parse(fd.read())


# Initialize dict to map approval statuses to drug names
group_lookup = defaultdict(list)
num_drugs = len(doc['drugbank']['drug'])

for i in range(num_drugs):
    drug_name = doc['drugbank']['drug'][i]['name']
    drug_group = doc['drugbank']['drug'][i]['groups']['group']

    # When multiple status are given, drug_group will be an array of str
    if isinstance(drug_group, str):
        group_lookup[drug_name].append(drug_group)
    else:
        group_lookup[drug_name].extend(drug_group)


# Write lookup to JSON file
with open("../Datasets/drugbank_approval_status.json", "w") as fp:
    json.dump(group_lookup, fp)
