#
# Get FDA approval status for LINCS drugs using Drugbank.ca extracted lookup
#
# Must be run after extract_drugbank_approval_status.py, which creates
# drugbank_approval_status.json containing status for all Drugbank drugs.
#
# Output a new file lincs_approval_status.json, a map of each LINCS drug
# to the approval status(es) found for it in Drugbank, or "N/A" if the
# drug is not in Drugbank db.
#

import json
import pandas as pd
from collections import defaultdict


# Load Drugbank.ca approval lookup
with open('../Datasets/drugbank_approval_status.json') as fp1:
    drugbank_approval_lookup = json.loads(fp1.read())

# Lowercase all Drugbank drug names (the keys in the dict)
for drug in set(drugbank_approval_lookup.keys()):
    drugbank_approval_lookup[drug.lower()] = drugbank_approval_lookup.pop(drug)


# Need map of <Lincs drug> -> [Approval statuses]
lincs_approval = defaultdict(list)
found = 0

# Go thru all LINCS drug names, pull from this file created in create_zscore_matrix.r
lincs_drugs_listing = pd.read_csv("../Datasets/all_lincs_drug_names.csv")
for lincs_drug in lincs_drugs_listing['x']:

    # Lowercase the LINCS drug name, see if found in Drugbank.ca lookup
    if lincs_drug.lower() in drugbank_approval_lookup:
        lincs_approval[lincs_drug] = drugbank_approval_lookup[lincs_drug.lower()]
        found += 1
    else:
        # TODO: Find FDA statuses elsewhere?
        lincs_approval[lincs_drug] = ["N/A"]


# Write LINCS approval map
print("Found", found, ", still need status for", len(lincs_approval)-found, "LINCS drugs")
with open("../Datasets/lincs_approval_status.json", "w") as fp:
    json.dump(lincs_approval, fp)
    print("Wrote LINCS status' to ../Datasets/lincs_approval_status.json")
